"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetadataOption:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetadataOptionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetadataOption.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METADATA_OPTION_UNSPECIFIED: _MetadataOption.ValueType  # 0
    """Option is default"""
    ENABLED: _MetadataOption.ValueType  # 1
    """Option is enabled"""
    DISABLED: _MetadataOption.ValueType  # 2
    """Option is disabled"""

class MetadataOption(_MetadataOption, metaclass=_MetadataOptionEnumTypeWrapper): ...

METADATA_OPTION_UNSPECIFIED: MetadataOption.ValueType  # 0
"""Option is default"""
ENABLED: MetadataOption.ValueType  # 1
"""Option is enabled"""
DISABLED: MetadataOption.ValueType  # 2
"""Option is disabled"""
global___MetadataOption = MetadataOption

@typing.final
class Container(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Container._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Container._Status.ValueType  # 0
        CREATING: Container._Status.ValueType  # 1
        """Container is being created."""
        ACTIVE: Container._Status.ValueType  # 2
        """Container is ready for use."""
        DELETING: Container._Status.ValueType  # 3
        """Container is being deleted."""
        ERROR: Container._Status.ValueType  # 4
        """Container failed. The only allowed action is delete."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Container.Status.ValueType  # 0
    CREATING: Container.Status.ValueType  # 1
    """Container is being created."""
    ACTIVE: Container.Status.ValueType  # 2
    """Container is ready for use."""
    DELETING: Container.Status.ValueType  # 3
    """Container is being deleted."""
    ERROR: Container.Status.ValueType  # 4
    """Container failed. The only allowed action is delete."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the container. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the container belongs to."""
    name: builtins.str
    """Name of the container. The name is unique within the folder."""
    description: builtins.str
    """Description of the container."""
    url: builtins.str
    """URL that needs to be requested to call the container."""
    status: global___Container.Status.ValueType
    """Status of the container."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the container."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Container labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        url: builtins.str = ...,
        status: global___Container.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status", "url", b"url"]) -> None: ...

global___Container = Container

@typing.final
class Revision(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Revision._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Revision._Status.ValueType  # 0
        CREATING: Revision._Status.ValueType  # 1
        """Revision is being created."""
        ACTIVE: Revision._Status.ValueType  # 2
        """Revision is currently used by the container."""
        OBSOLETE: Revision._Status.ValueType  # 3
        """Revision is not used by the container. May be deleted later."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Revision.Status.ValueType  # 0
    CREATING: Revision.Status.ValueType  # 1
    """Revision is being created."""
    ACTIVE: Revision.Status.ValueType  # 2
    """Revision is currently used by the container."""
    OBSOLETE: Revision.Status.ValueType  # 3
    """Revision is not used by the container. May be deleted later."""

    ID_FIELD_NUMBER: builtins.int
    CONTAINER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    CONCURRENCY_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SECRETS_FIELD_NUMBER: builtins.int
    CONNECTIVITY_FIELD_NUMBER: builtins.int
    PROVISION_POLICY_FIELD_NUMBER: builtins.int
    SCALING_POLICY_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    STORAGE_MOUNTS_FIELD_NUMBER: builtins.int
    MOUNTS_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    METADATA_OPTIONS_FIELD_NUMBER: builtins.int
    ASYNC_INVOCATION_CONFIG_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the revision."""
    container_id: builtins.str
    """ID of the container that the revision belongs to."""
    description: builtins.str
    """Description of the revision."""
    concurrency: builtins.int
    """The number of concurrent requests allowed per container instance."""
    service_account_id: builtins.str
    """ID of the service account associated with the revision."""
    status: global___Revision.Status.ValueType
    """Status of the revision."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the revision."""

    @property
    def image(self) -> global___Image:
        """Image configuration for the revision."""

    @property
    def resources(self) -> global___Resources:
        """Resources allocated to the revision."""

    @property
    def execution_timeout(self) -> google.protobuf.duration_pb2.Duration:
        """Timeout for the execution of the revision.

        If the timeout is exceeded, Serverless Containers responds with a 504 HTTP code.
        """

    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Secret]:
        """Yandex Lockbox secrets to be used by the revision."""

    @property
    def connectivity(self) -> global___Connectivity:
        """Network access. If specified the revision will be attached to specified network/subnet(s)."""

    @property
    def provision_policy(self) -> global___ProvisionPolicy:
        """Policy for provisioning instances of the revision.

        The policy is only applied when the revision is ACTIVE.
        """

    @property
    def scaling_policy(self) -> global___ScalingPolicy:
        """Policy for scaling instances of the revision."""

    @property
    def log_options(self) -> global___LogOptions:
        """Options for logging from the container."""

    @property
    def storage_mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageMount]:
        """S3 mounts to be used by the revision."""

    @property
    def mounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Mount]:
        """Mounts to be used by the revision."""

    @property
    def runtime(self) -> global___Runtime:
        """The container's execution mode."""

    @property
    def metadata_options(self) -> global___MetadataOptions:
        """Metadata options for the revision."""

    @property
    def async_invocation_config(self) -> global___AsyncInvocationConfig:
        """Config for asynchronous invocations of the revision."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        container_id: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        image: global___Image | None = ...,
        resources: global___Resources | None = ...,
        execution_timeout: google.protobuf.duration_pb2.Duration | None = ...,
        concurrency: builtins.int = ...,
        service_account_id: builtins.str = ...,
        status: global___Revision.Status.ValueType = ...,
        secrets: collections.abc.Iterable[global___Secret] | None = ...,
        connectivity: global___Connectivity | None = ...,
        provision_policy: global___ProvisionPolicy | None = ...,
        scaling_policy: global___ScalingPolicy | None = ...,
        log_options: global___LogOptions | None = ...,
        storage_mounts: collections.abc.Iterable[global___StorageMount] | None = ...,
        mounts: collections.abc.Iterable[global___Mount] | None = ...,
        runtime: global___Runtime | None = ...,
        metadata_options: global___MetadataOptions | None = ...,
        async_invocation_config: global___AsyncInvocationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "connectivity", b"connectivity", "created_at", b"created_at", "execution_timeout", b"execution_timeout", "image", b"image", "log_options", b"log_options", "metadata_options", b"metadata_options", "provision_policy", b"provision_policy", "resources", b"resources", "runtime", b"runtime", "scaling_policy", b"scaling_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["async_invocation_config", b"async_invocation_config", "concurrency", b"concurrency", "connectivity", b"connectivity", "container_id", b"container_id", "created_at", b"created_at", "description", b"description", "execution_timeout", b"execution_timeout", "id", b"id", "image", b"image", "log_options", b"log_options", "metadata_options", b"metadata_options", "mounts", b"mounts", "provision_policy", b"provision_policy", "resources", b"resources", "runtime", b"runtime", "scaling_policy", b"scaling_policy", "secrets", b"secrets", "service_account_id", b"service_account_id", "status", b"status", "storage_mounts", b"storage_mounts"]) -> None: ...

global___Revision = Revision

@typing.final
class Image(google.protobuf.message.Message):
    """Revision image specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class EnvironmentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_DIGEST_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    WORKING_DIR_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """Image URL, that is used by the revision."""
    image_digest: builtins.str
    """Digest of the image. Calculated at creation time."""
    working_dir: builtins.str
    """Override for the image's WORKDIR."""
    @property
    def command(self) -> global___Command:
        """Override for the image's ENTRYPOINT."""

    @property
    def args(self) -> global___Args:
        """Override for the image's CMD."""

    @property
    def environment(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional environment for the container."""

    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        image_digest: builtins.str = ...,
        command: global___Command | None = ...,
        args: global___Args | None = ...,
        environment: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        working_dir: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["args", b"args", "command", b"command"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["args", b"args", "command", b"command", "environment", b"environment", "image_digest", b"image_digest", "image_url", b"image_url", "working_dir", b"working_dir"]) -> None: ...

global___Image = Image

@typing.final
class Command(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Command that will override ENTRYPOINT of an image.

        Commands will be executed as is. The runtime will not substitute environment
        variables or execute shell commands. If one wants to do that, they should
        invoke shell interpreter with an appropriate shell script.
        """

    def __init__(
        self,
        *,
        command: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["command", b"command"]) -> None: ...

global___Command = Command

@typing.final
class Args(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Arguments that will override CMD of an image.

        Arguments will be passed as is. The runtime will not substitute environment
        variables or execute shell commands. If one wants to do that, they should
        invoke shell interpreter with an appropriate shell script.
        """

    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["args", b"args"]) -> None: ...

global___Args = Args

@typing.final
class Resources(google.protobuf.message.Message):
    """Resources allocated to a revision."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMORY_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    memory: builtins.int
    """Amount of memory available to the revision, specified in bytes, multiple of 128MB."""
    cores: builtins.int
    """Number of cores available to the revision."""
    core_fraction: builtins.int
    """Specifies baseline performance for a core in percent, multiple of 5%.
    Should be 100% for cores > 1.
    """
    def __init__(
        self,
        *,
        memory: builtins.int = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "memory", b"memory"]) -> None: ...

global___Resources = Resources

@typing.final
class ProvisionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    min_instances: builtins.int
    """Minimum number of guaranteed provisioned container instances for all zones
    in total.
    """
    def __init__(
        self,
        *,
        min_instances: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["min_instances", b"min_instances"]) -> None: ...

global___ProvisionPolicy = ProvisionPolicy

@typing.final
class Secret(google.protobuf.message.Message):
    """Secret that is available to the container at run time."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_VARIABLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of Yandex Lockbox secret."""
    version_id: builtins.str
    """ID of Yandex Lockbox secret."""
    key: builtins.str
    """Key in secret's payload, which value to be delivered into container environment."""
    environment_variable: builtins.str
    """Environment variable in which secret's value is delivered."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version_id: builtins.str = ...,
        key: builtins.str = ...,
        environment_variable: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["environment_variable", b"environment_variable", "reference", b"reference"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["environment_variable", b"environment_variable", "id", b"id", "key", b"key", "reference", b"reference", "version_id", b"version_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["reference", b"reference"]) -> typing.Literal["environment_variable"] | None: ...

global___Secret = Secret

@typing.final
class Connectivity(google.protobuf.message.Message):
    """Revision connectivity specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    network_id: builtins.str
    """Network the revision will have access to."""
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The list of subnets (from the same network) the revision can be attached to.

        Deprecated, it is sufficient to specify only network_id, without the list of subnet_ids.
        """

    def __init__(
        self,
        *,
        network_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["network_id", b"network_id", "subnet_ids", b"subnet_ids"]) -> None: ...

global___Connectivity = Connectivity

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from container disabled."""
    log_group_id: builtins.str
    """Entry should be written to log group resolved by ID."""
    folder_id: builtins.str
    """Entry should be written to default log group for specified folder."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum log entry level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions

@typing.final
class ScalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_INSTANCES_LIMIT_FIELD_NUMBER: builtins.int
    ZONE_REQUESTS_LIMIT_FIELD_NUMBER: builtins.int
    zone_instances_limit: builtins.int
    """Upper limit for instance count in each zone.
    0 means no limit.
    """
    zone_requests_limit: builtins.int
    """Upper limit of requests count in each zone.
    0 means no limit.
    """
    def __init__(
        self,
        *,
        zone_instances_limit: builtins.int = ...,
        zone_requests_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["zone_instances_limit", b"zone_instances_limit", "zone_requests_limit", b"zone_requests_limit"]) -> None: ...

global___ScalingPolicy = ScalingPolicy

@typing.final
class StorageMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    MOUNT_POINT_PATH_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    """S3 bucket name for mounting."""
    prefix: builtins.str
    """S3 bucket prefix for mounting."""
    read_only: builtins.bool
    """Is mount read only."""
    mount_point_path: builtins.str
    """Mount point path inside the container for mounting."""
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        prefix: builtins.str = ...,
        read_only: builtins.bool = ...,
        mount_point_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "mount_point_path", b"mount_point_path", "prefix", b"prefix", "read_only", b"read_only"]) -> None: ...

global___StorageMount = StorageMount

@typing.final
class Mount(google.protobuf.message.Message):
    """Mount contains an information about version's external storage mount"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Mount._Mode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MODE_UNSPECIFIED: Mount._Mode.ValueType  # 0
        READ_ONLY: Mount._Mode.ValueType  # 1
        READ_WRITE: Mount._Mode.ValueType  # 2

    class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
    MODE_UNSPECIFIED: Mount.Mode.ValueType  # 0
    READ_ONLY: Mount.Mode.ValueType  # 1
    READ_WRITE: Mount.Mode.ValueType  # 2

    @typing.final
    class ObjectStorage(google.protobuf.message.Message):
        """ObjectStorage as a mount"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BUCKET_ID_FIELD_NUMBER: builtins.int
        PREFIX_FIELD_NUMBER: builtins.int
        bucket_id: builtins.str
        """ObjectStorage bucket name for mounting."""
        prefix: builtins.str
        """ObjectStorage bucket prefix for mounting."""
        def __init__(
            self,
            *,
            bucket_id: builtins.str = ...,
            prefix: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "prefix", b"prefix"]) -> None: ...

    @typing.final
    class DiskSpec(google.protobuf.message.Message):
        """Disk as a mount"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        BLOCK_SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        """The size of disk for mount in bytes"""
        block_size: builtins.int
        """Optional block size of disk for mount in bytes"""
        def __init__(
            self,
            *,
            size: builtins.int = ...,
            block_size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["block_size", b"block_size", "size", b"size"]) -> None: ...

    MOUNT_POINT_PATH_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    OBJECT_STORAGE_FIELD_NUMBER: builtins.int
    EPHEMERAL_DISK_SPEC_FIELD_NUMBER: builtins.int
    mount_point_path: builtins.str
    """The absolute mount point path inside the container for mounting."""
    mode: global___Mount.Mode.ValueType
    """Mount's mode"""
    @property
    def object_storage(self) -> global___Mount.ObjectStorage:
        """Object storage mounts"""

    @property
    def ephemeral_disk_spec(self) -> global___Mount.DiskSpec:
        """Working disk (worker-local non-shared read-write NBS disk templates)"""

    def __init__(
        self,
        *,
        mount_point_path: builtins.str = ...,
        mode: global___Mount.Mode.ValueType = ...,
        object_storage: global___Mount.ObjectStorage | None = ...,
        ephemeral_disk_spec: global___Mount.DiskSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ephemeral_disk_spec", b"ephemeral_disk_spec", "object_storage", b"object_storage", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ephemeral_disk_spec", b"ephemeral_disk_spec", "mode", b"mode", "mount_point_path", b"mount_point_path", "object_storage", b"object_storage", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["object_storage", "ephemeral_disk_spec"] | None: ...

global___Mount = Mount

@typing.final
class Runtime(google.protobuf.message.Message):
    """The container's execution mode"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Http(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Task(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    HTTP_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    @property
    def http(self) -> global___Runtime.Http:
        """The classic one. You need to run an HTTP server inside the container."""

    @property
    def task(self) -> global___Runtime.Task:
        """We run a process from ENTRYPOINT inside the container for each user request."""

    def __init__(
        self,
        *,
        http: global___Runtime.Http | None = ...,
        task: global___Runtime.Task | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["http", b"http", "task", b"task", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["http", b"http", "task", b"task", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["http", "task"] | None: ...

global___Runtime = Runtime

@typing.final
class MetadataOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GCE_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    AWS_V1_HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    gce_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to GCE flavored metadata"""
    aws_v1_http_endpoint: global___MetadataOption.ValueType
    """Enabled access to AWS flavored metadata (IMDSv1)"""
    def __init__(
        self,
        *,
        gce_http_endpoint: global___MetadataOption.ValueType = ...,
        aws_v1_http_endpoint: global___MetadataOption.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["aws_v1_http_endpoint", b"aws_v1_http_endpoint", "gce_http_endpoint", b"gce_http_endpoint"]) -> None: ...

global___MetadataOptions = MetadataOptions

@typing.final
class AsyncInvocationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """Optional id of service account with permission to invoke container."""
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___AsyncInvocationConfig = AsyncInvocationConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.mdb.spqr.v1.config_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Shard(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the shard."""
    cluster_id: builtins.str
    """ID of the cluster that the shard belongs to."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name"]) -> None: ...

global___Shard = Shard

@typing.final
class ShardSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARD_NAME_FIELD_NUMBER: builtins.int
    MDB_POSTGRESQL_FIELD_NUMBER: builtins.int
    shard_name: builtins.str
    """Name of the SPQR shard to create."""
    @property
    def mdb_postgresql(self) -> yandex.cloud.mdb.spqr.v1.config_pb2.MDBPostgreSQL:
        """Properties of the MDB PostgreSQL cluster"""

    def __init__(
        self,
        *,
        shard_name: builtins.str = ...,
        mdb_postgresql: yandex.cloud.mdb.spqr.v1.config_pb2.MDBPostgreSQL | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Spec", b"Spec", "mdb_postgresql", b"mdb_postgresql"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Spec", b"Spec", "mdb_postgresql", b"mdb_postgresql", "shard_name", b"shard_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Spec", b"Spec"]) -> typing.Literal["mdb_postgresql"] | None: ...

global___ShardSpec = ShardSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iot.devices.v1.device_pb2
import yandex.cloud.iot.devices.v1.device_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DeviceServiceStub:
    """A set of methods for managing devices."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.GetDeviceRequest,
        yandex.cloud.iot.devices.v1.device_pb2.Device,
    ]
    """Returns the specified device.

    To get the list of available devices, make a [List] request.
    """

    GetByName: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.GetByNameDeviceRequest,
        yandex.cloud.iot.devices.v1.device_pb2.Device,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesResponse,
    ]
    """Retrieves the list of devices in the specified registry."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.CreateDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a device in the specified registry."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.UpdateDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified device."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified device."""

    ListCertificates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesResponse,
    ]
    """Retrieves the list of device certificates for the specified device."""

    AddCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.AddDeviceCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified device certificate."""

    ListPasswords: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified device."""

    AddPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.AddDevicePasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified device."""

    DeletePassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDevicePasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsResponse,
    ]
    """Lists operations for the specified device."""

class DeviceServiceAsyncStub:
    """A set of methods for managing devices."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.GetDeviceRequest,
        yandex.cloud.iot.devices.v1.device_pb2.Device,
    ]
    """Returns the specified device.

    To get the list of available devices, make a [List] request.
    """

    GetByName: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.GetByNameDeviceRequest,
        yandex.cloud.iot.devices.v1.device_pb2.Device,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesResponse,
    ]
    """Retrieves the list of devices in the specified registry."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.CreateDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a device in the specified registry."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.UpdateDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified device."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified device."""

    ListCertificates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesResponse,
    ]
    """Retrieves the list of device certificates for the specified device."""

    AddCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.AddDeviceCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified device certificate."""

    ListPasswords: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified device."""

    AddPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.AddDevicePasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified device."""

    DeletePassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDevicePasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsRequest,
        yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsResponse,
    ]
    """Lists operations for the specified device."""

class DeviceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing devices."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.GetDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_pb2.Device, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_pb2.Device]]:
        """Returns the specified device.

        To get the list of available devices, make a [List] request.
        """

    @abc.abstractmethod
    def GetByName(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.GetByNameDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_pb2.Device, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_pb2.Device]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicesResponse]]:
        """Retrieves the list of devices in the specified registry."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.CreateDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a device in the specified registry."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.UpdateDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified device."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified device."""

    @abc.abstractmethod
    def ListCertificates(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceCertificatesResponse]]:
        """Retrieves the list of device certificates for the specified device."""

    @abc.abstractmethod
    def AddCertificate(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.AddDeviceCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a certificate."""

    @abc.abstractmethod
    def DeleteCertificate(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDeviceCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified device certificate."""

    @abc.abstractmethod
    def ListPasswords(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_service_pb2.ListDevicePasswordsResponse]]:
        """Retrieves the list of passwords for the specified device."""

    @abc.abstractmethod
    def AddPassword(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.AddDevicePasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds password for the specified device."""

    @abc.abstractmethod
    def DeletePassword(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.DeleteDevicePasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified password."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.device_service_pb2.ListDeviceOperationsResponse]]:
        """Lists operations for the specified device."""

def add_DeviceServiceServicer_to_server(servicer: DeviceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/file_pointer.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/file_pointer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import object_storage_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_object__storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/loadtesting/api/v1/test/file_pointer.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x39yandex/cloud/loadtesting/api/v1/test/object_storage.proto\"l\n\x0b\x46ilePointer\x12M\n\x0eobject_storage\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.loadtesting.api.v1.test.ObjectStorageH\x00\x42\x0e\n\x0c\x66ile_pointerBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_FILEPOINTER']._serialized_start=156
  _globals['_FILEPOINTER']._serialized_end=264
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto\x12 yandex.cloud.mdb.mysql.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xac\x41\n\x0eMysqlConfig8_0\x12K\n\x17innodb_buffer_pool_size\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t>=5242880\x12\x42\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x12\x35\n\x0flong_query_time\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\x0bgeneral_log\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\taudit_log\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x08sql_mode\x18\x06 \x03(\x0e\x32\x38.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.SQLMode\x12L\n\x12max_allowed_packet\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x31\x30\x32\x34-1073741824\x12\x62\n\x1d\x64\x65\x66\x61ult_authentication_plugin\x18\x08 \x01(\x0e\x32;.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.AuthPlugin\x12L\n\x1einnodb_flush_log_at_trx_commit\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x31-2\x12J\n\x18innodb_lock_wait_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-28800\x12\x64\n\x15transaction_isolation\x18\x0b \x01(\x0e\x32\x45.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.TransactionIsolation\x12>\n\x1ainnodb_print_all_deadlocks\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x10net_read_timeout\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1200\x12\x42\n\x11net_write_timeout\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1200\x12I\n\x14group_concat_max_len\x18\x0f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n4-33554432\x12G\n\x0etmp_table_size\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x32\x34-536870912\x12M\n\x13max_heap_table_size\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x31\x36\x33\x38\x34-536870912\x12\x19\n\x11\x64\x65\x66\x61ult_time_zone\x18\x12 \x01(\t\x12\x1c\n\x14\x63haracter_set_server\x18\x13 \x01(\t\x12\x18\n\x10\x63ollation_server\x18\x14 \x01(\t\x12>\n\x1ainnodb_adaptive_hash_index\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x16innodb_numa_interleave\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12R\n\x16innodb_log_buffer_size\x18\x17 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x15\xfa\xc7\x31\x11\x31\x30\x34\x38\x35\x37\x36-268435456\x12S\n\x14innodb_log_file_size\x18\x18 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x18\xfa\xc7\x31\x14\x32\x36\x38\x34\x33\x35\x34\x35\x36-4294967296\x12G\n\x12innodb_io_capacity\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n100-100000\x12K\n\x16innodb_io_capacity_max\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n100-100000\x12\x45\n\x16innodb_read_io_threads\x18\x1b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-16\x12\x46\n\x17innodb_write_io_threads\x18\x1c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-16\x12\x43\n\x14innodb_purge_threads\x18\x1d \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-16\x12J\n\x19innodb_thread_concurrency\x18\x1e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-1000\x12W\n\x1einnodb_temp_data_file_max_size\x18\x1f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x30-107374182400\x12\x44\n\x11thread_cache_size\x18  \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-10000\x12\x46\n\x0cthread_stack\x18! \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x13\xfa\xc7\x31\x0f\x31\x33\x31\x30\x37\x32-16777216\x12H\n\x10join_buffer_size\x18\" \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r1024-16777216\x12H\n\x10sort_buffer_size\x18# \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r1024-16777216\x12K\n\x16table_definition_cache\x18$ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n400-524288\x12\x45\n\x10table_open_cache\x18% \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n400-524288\x12I\n\x1atable_open_cache_instances\x18& \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-32\x12\x43\n\x1f\x65xplicit_defaults_for_timestamp\x18\' \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12J\n\x18\x61uto_increment_increment\x18( \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-65535\x12G\n\x15\x61uto_increment_offset\x18) \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x31-65535\x12<\n\x0bsync_binlog\x18* \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x30-4096\x12I\n\x11\x62inlog_cache_size\x18+ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x11\xfa\xc7\x31\r4096-67108864\x12P\n\x1e\x62inlog_group_commit_sync_delay\x18, \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x30-50000\x12Y\n\x10\x62inlog_row_image\x18- \x01(\x0e\x32?.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.BinlogRowImage\x12@\n\x1c\x62inlog_rows_query_log_events\x18. \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12W\n)rpl_semi_sync_master_wait_for_slave_count\x18/ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x31-2\x12_\n\x13slave_parallel_type\x18\x30 \x01(\x0e\x32\x42.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.SlaveParallelType\x12\x45\n\x16slave_parallel_workers\x18\x31 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-64\x12\x45\n\x11regexp_time_limit\x18\x32 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-1048576\x12\\\n\x19mdb_preserve_binlog_bytes\x18\x33 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x1c\xfa\xc7\x31\x18\x31\x30\x37\x33\x37\x34\x31\x38\x32\x34-1099511627776\x12G\n\x13interactive_timeout\x18\x34 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t600-86400\x12@\n\x0cwait_timeout\x18\x35 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t600-86400\x12P\n\x1bmdb_offline_mode_enable_lag\x18\x36 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n600-432000\x12O\n\x1cmdb_offline_mode_disable_lag\x18\x37 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x30-86400\x12X\n\x1crange_optimizer_max_mem_size\x18\x38 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x15\xfa\xc7\x31\x11\x31\x30\x34\x38\x35\x37\x36-268435456\x12\x32\n\x0eslow_query_log\x18\x39 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x46\n slow_query_log_always_write_time\x18: \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\\\n\x12log_slow_rate_type\x18; \x01(\x0e\x32@.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.LogSlowRateType\x12\x44\n\x13log_slow_rate_limit\x18< \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1000\x12:\n\x16log_slow_sp_statements\x18= \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12[\n\x0flog_slow_filter\x18> \x03(\x0e\x32\x42.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.LogSlowFilterType\x12M\n\x1bmdb_priority_choice_max_lag\x18? \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x30-86400\x12\x45\n\x10innodb_page_size\x18@ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n4096-65536\x12]\n innodb_online_alter_log_max_size\x18\x41 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x16\xfa\xc7\x31\x12\x36\x35\x35\x33\x36-107374182400\x12G\n\x18innodb_ft_min_token_size\x18\x42 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-16\x12H\n\x18innodb_ft_max_token_size\x18\x43 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31\x30-84\x12\x44\n\x16lower_case_table_names\x18\x44 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-1\x12\x46\n\x16max_sp_recursion_depth\x18\x45 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-255\x12\x46\n\x18innodb_compression_level\x18\x46 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-9\x12\x84\x01\n&binlog_transaction_dependency_tracking\x18G \x01(\x0e\x32T.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.BinlogTransactionDependencyTracking\x12.\n\nautocommit\x18H \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14innodb_status_output\x18I \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12innodb_strict_mode\x18J \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12G\n#innodb_print_lock_wait_timeout_info\x18K \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x13log_error_verbosity\x18L \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x31-3\x12\x45\n\x11max_digest_length\x18M \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-1048576\x12\x46\n\x11lock_wait_timeout\x18N \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0e\xfa\xc7\x31\n1-31536000\x12K\n\x17max_prepared_stmt_count\x18O \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\r\xfa\xc7\x31\t0-4194304\x12\x18\n\x10optimizer_switch\x18P \x01(\t\x12\x45\n\x16optimizer_search_depth\x18Q \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x30-62\x12,\n\x08userstat\x18R \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12I\n\x12max_execution_time\x18S \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x10\xfa\xc7\x31\x0c\x30-4294967295\x12Y\n\x10\x61udit_log_policy\x18T \x01(\x0e\x32?.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.AuditLogPolicy\x12J\n&replication_sender_observe_commit_only\x18U \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12Q\n-replication_optimize_for_static_plugin_config\x18V \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n\x15innodb_lru_scan_depth\x18W \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\xfa\xc7\x31\x0e\x31\x30\x30-4294967295\x12;\n\x17sql_require_primary_key\x18X \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rmdb_force_ssl\x18Y \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12g\n\x17innodb_change_buffering\x18Z \x01(\x0e\x32\x46.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0.InnodbChangeBuffering\x12\x42\n\x14max_write_lock_count\x18[ \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=1\"\x88\x04\n\x07SQLMode\x12\x17\n\x13SQLMODE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41LLOW_INVALID_DATES\x10\x01\x12\x0f\n\x0b\x41NSI_QUOTES\x10\x02\x12\x1e\n\x1a\x45RROR_FOR_DIVISION_BY_ZERO\x10\x03\x12\x17\n\x13HIGH_NOT_PRECEDENCE\x10\x04\x12\x10\n\x0cIGNORE_SPACE\x10\x05\x12\x19\n\x15NO_AUTO_VALUE_ON_ZERO\x10\x06\x12\x18\n\x14NO_BACKSLASH_ESCAPES\x10\x07\x12\x1a\n\x16NO_ENGINE_SUBSTITUTION\x10\x08\x12\x1b\n\x17NO_UNSIGNED_SUBTRACTION\x10\t\x12\x10\n\x0cNO_ZERO_DATE\x10\n\x12\x13\n\x0fNO_ZERO_IN_DATE\x10\x0b\x12\x16\n\x12ONLY_FULL_GROUP_BY\x10\x0f\x12\x1b\n\x17PAD_CHAR_TO_FULL_LENGTH\x10\x10\x12\x13\n\x0fPIPES_AS_CONCAT\x10\x11\x12\x11\n\rREAL_AS_FLOAT\x10\x12\x12\x15\n\x11STRICT_ALL_TABLES\x10\x13\x12\x17\n\x13STRICT_TRANS_TABLES\x10\x14\x12\x1c\n\x18TIME_TRUNCATE_FRACTIONAL\x10\x15\x12\x08\n\x04\x41NSI\x10\x16\x12\x0f\n\x0bTRADITIONAL\x10\x17\x12\x14\n\x10NO_DIR_IN_CREATE\x10\x18\"\x9f\x01\n\nAuthPlugin\x12\x1b\n\x17\x41UTH_PLUGIN_UNSPECIFIED\x10\x00\x12\x19\n\x15MYSQL_NATIVE_PASSWORD\x10\x01\x12\x19\n\x15\x43\x41\x43HING_SHA2_PASSWORD\x10\x02\x12\x13\n\x0fSHA256_PASSWORD\x10\x03\x12\x12\n\x0eMYSQL_NO_LOGIN\x10\x04\x12\x15\n\x11MDB_IAMPROXY_AUTH\x10\x05\"x\n\x14TransactionIsolation\x12%\n!TRANSACTION_ISOLATION_UNSPECIFIED\x10\x00\x12\x12\n\x0eREAD_COMMITTED\x10\x01\x12\x13\n\x0fREPEATABLE_READ\x10\x02\x12\x10\n\x0cSERIALIZABLE\x10\x03\"U\n\x0e\x42inlogRowImage\x12 \n\x1c\x42INLOG_ROW_IMAGE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x0b\n\x07MINIMAL\x10\x02\x12\n\n\x06NOBLOB\x10\x03\"Y\n\x11SlaveParallelType\x12#\n\x1fSLAVE_PARALLEL_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44\x41TABASE\x10\x01\x12\x11\n\rLOGICAL_CLOCK\x10\x02\"M\n\x0fLogSlowRateType\x12\"\n\x1eLOG_SLOW_RATE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\t\n\x05QUERY\x10\x02\"\xa1\x01\n\x11LogSlowFilterType\x12$\n LOG_SLOW_FILTER_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tFULL_SCAN\x10\x01\x12\r\n\tFULL_JOIN\x10\x02\x12\r\n\tTMP_TABLE\x10\x03\x12\x15\n\x11TMP_TABLE_ON_DISK\x10\x04\x12\x0c\n\x08\x46ILESORT\x10\x05\x12\x14\n\x10\x46ILESORT_ON_DISK\x10\x06\"\x93\x01\n#BinlogTransactionDependencyTracking\x12\x36\n2BINLOG_TRANSACTION_DEPENDENCY_TRACKING_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43OMMIT_ORDER\x10\x01\x12\x0c\n\x08WRITESET\x10\x02\x12\x14\n\x10WRITESET_SESSION\x10\x03\"^\n\x0e\x41uditLogPolicy\x12 \n\x1c\x41UDIT_LOG_POLICY_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\n\n\x06LOGINS\x10\x02\x12\x0b\n\x07QUERIES\x10\x03\x12\x08\n\x04NONE\x10\x04\"\x96\x02\n\x15InnodbChangeBuffering\x12\'\n#INNODB_CHANGE_BUFFERING_UNSPECIFIED\x10\x00\x12 \n\x1cINNODB_CHANGE_BUFFERING_NONE\x10\x01\x12#\n\x1fINNODB_CHANGE_BUFFERING_INSERTS\x10\x02\x12#\n\x1fINNODB_CHANGE_BUFFERING_DELETES\x10\x03\x12#\n\x1fINNODB_CHANGE_BUFFERING_CHANGES\x10\x04\x12\"\n\x1eINNODB_CHANGE_BUFFERING_PURGES\x10\x05\x12\x1f\n\x1bINNODB_CHANGE_BUFFERING_ALL\x10\x06\"\xf0\x01\n\x11MysqlConfigSet8_0\x12J\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0\x12\x45\n\x0buser_config\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0\x12H\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.mysql.v1.config.MysqlConfig8_0Br\n$yandex.cloud.api.mdb.mysql.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1/config;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1.config.mysql8_0_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.mdb.mysql.v1.configZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1/config;mysql'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_buffer_pool_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_buffer_pool_size']._serialized_options = b'\372\3071\t>=5242880'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_connections']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_connections']._serialized_options = b'\372\3071\01010-16384'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_allowed_packet']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_allowed_packet']._serialized_options = b'\372\3071\0171024-1073741824'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_flush_log_at_trx_commit']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_flush_log_at_trx_commit']._serialized_options = b'\372\3071\0031-2'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_lock_wait_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_lock_wait_timeout']._serialized_options = b'\372\3071\0071-28800'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['net_read_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['net_read_timeout']._serialized_options = b'\372\3071\0061-1200'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['net_write_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['net_write_timeout']._serialized_options = b'\372\3071\0061-1200'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['group_concat_max_len']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['group_concat_max_len']._serialized_options = b'\372\3071\n4-33554432'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['tmp_table_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['tmp_table_size']._serialized_options = b'\372\3071\0161024-536870912'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_heap_table_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_heap_table_size']._serialized_options = b'\372\3071\01716384-536870912'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_log_buffer_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_log_buffer_size']._serialized_options = b'\372\3071\0211048576-268435456'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_log_file_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_log_file_size']._serialized_options = b'\372\3071\024268435456-4294967296'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_io_capacity']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_io_capacity']._serialized_options = b'\372\3071\n100-100000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_io_capacity_max']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_io_capacity_max']._serialized_options = b'\372\3071\n100-100000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_read_io_threads']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_read_io_threads']._serialized_options = b'\372\3071\0041-16'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_write_io_threads']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_write_io_threads']._serialized_options = b'\372\3071\0041-16'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_purge_threads']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_purge_threads']._serialized_options = b'\372\3071\0041-16'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_thread_concurrency']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_thread_concurrency']._serialized_options = b'\372\3071\0060-1000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_temp_data_file_max_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_temp_data_file_max_size']._serialized_options = b'\372\3071\0160-107374182400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['thread_cache_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['thread_cache_size']._serialized_options = b'\372\3071\01010-10000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['thread_stack']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['thread_stack']._serialized_options = b'\372\3071\017131072-16777216'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['join_buffer_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['join_buffer_size']._serialized_options = b'\372\3071\r1024-16777216'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['sort_buffer_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['sort_buffer_size']._serialized_options = b'\372\3071\r1024-16777216'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_definition_cache']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_definition_cache']._serialized_options = b'\372\3071\n400-524288'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_open_cache']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_open_cache']._serialized_options = b'\372\3071\n400-524288'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_open_cache_instances']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['table_open_cache_instances']._serialized_options = b'\372\3071\0041-32'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['auto_increment_increment']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['auto_increment_increment']._serialized_options = b'\372\3071\0071-65535'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['auto_increment_offset']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['auto_increment_offset']._serialized_options = b'\372\3071\0071-65535'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['sync_binlog']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['sync_binlog']._serialized_options = b'\372\3071\0060-4096'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['binlog_cache_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['binlog_cache_size']._serialized_options = b'\372\3071\r4096-67108864'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['binlog_group_commit_sync_delay']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['binlog_group_commit_sync_delay']._serialized_options = b'\372\3071\0070-50000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['rpl_semi_sync_master_wait_for_slave_count']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['rpl_semi_sync_master_wait_for_slave_count']._serialized_options = b'\372\3071\0031-2'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['slave_parallel_workers']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['slave_parallel_workers']._serialized_options = b'\372\3071\0040-64'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['regexp_time_limit']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['regexp_time_limit']._serialized_options = b'\372\3071\t0-1048576'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_preserve_binlog_bytes']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_preserve_binlog_bytes']._serialized_options = b'\372\3071\0301073741824-1099511627776'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['interactive_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['interactive_timeout']._serialized_options = b'\372\3071\t600-86400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['wait_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['wait_timeout']._serialized_options = b'\372\3071\t600-86400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_offline_mode_enable_lag']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_offline_mode_enable_lag']._serialized_options = b'\372\3071\n600-432000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_offline_mode_disable_lag']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_offline_mode_disable_lag']._serialized_options = b'\372\3071\01060-86400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['range_optimizer_max_mem_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['range_optimizer_max_mem_size']._serialized_options = b'\372\3071\0211048576-268435456'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['log_slow_rate_limit']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['log_slow_rate_limit']._serialized_options = b'\372\3071\0061-1000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_priority_choice_max_lag']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['mdb_priority_choice_max_lag']._serialized_options = b'\372\3071\0070-86400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_page_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_page_size']._serialized_options = b'\372\3071\n4096-65536'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_online_alter_log_max_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_online_alter_log_max_size']._serialized_options = b'\372\3071\02265536-107374182400'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_ft_min_token_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_ft_min_token_size']._serialized_options = b'\372\3071\0040-16'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_ft_max_token_size']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_ft_max_token_size']._serialized_options = b'\372\3071\00510-84'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['lower_case_table_names']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['lower_case_table_names']._serialized_options = b'\372\3071\0030-1'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_sp_recursion_depth']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_sp_recursion_depth']._serialized_options = b'\372\3071\0050-255'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_compression_level']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_compression_level']._serialized_options = b'\372\3071\0030-9'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['log_error_verbosity']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['log_error_verbosity']._serialized_options = b'\372\3071\0031-3'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_digest_length']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_digest_length']._serialized_options = b'\372\3071\t0-1048576'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['lock_wait_timeout']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['lock_wait_timeout']._serialized_options = b'\372\3071\n1-31536000'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_prepared_stmt_count']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_prepared_stmt_count']._serialized_options = b'\372\3071\t0-4194304'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['optimizer_search_depth']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['optimizer_search_depth']._serialized_options = b'\372\3071\0040-62'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_execution_time']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_execution_time']._serialized_options = b'\372\3071\0140-4294967295'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_lru_scan_depth']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['innodb_lru_scan_depth']._serialized_options = b'\372\3071\016100-4294967295'
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_write_lock_count']._loaded_options = None
  _globals['_MYSQLCONFIG8_0'].fields_by_name['max_write_lock_count']._serialized_options = b'\372\3071\003>=1'
  _globals['_MYSQLCONFIG8_0']._serialized_start=149
  _globals['_MYSQLCONFIG8_0']._serialized_end=8513
  _globals['_MYSQLCONFIG8_0_SQLMODE']._serialized_start=6761
  _globals['_MYSQLCONFIG8_0_SQLMODE']._serialized_end=7281
  _globals['_MYSQLCONFIG8_0_AUTHPLUGIN']._serialized_start=7284
  _globals['_MYSQLCONFIG8_0_AUTHPLUGIN']._serialized_end=7443
  _globals['_MYSQLCONFIG8_0_TRANSACTIONISOLATION']._serialized_start=7445
  _globals['_MYSQLCONFIG8_0_TRANSACTIONISOLATION']._serialized_end=7565
  _globals['_MYSQLCONFIG8_0_BINLOGROWIMAGE']._serialized_start=7567
  _globals['_MYSQLCONFIG8_0_BINLOGROWIMAGE']._serialized_end=7652
  _globals['_MYSQLCONFIG8_0_SLAVEPARALLELTYPE']._serialized_start=7654
  _globals['_MYSQLCONFIG8_0_SLAVEPARALLELTYPE']._serialized_end=7743
  _globals['_MYSQLCONFIG8_0_LOGSLOWRATETYPE']._serialized_start=7745
  _globals['_MYSQLCONFIG8_0_LOGSLOWRATETYPE']._serialized_end=7822
  _globals['_MYSQLCONFIG8_0_LOGSLOWFILTERTYPE']._serialized_start=7825
  _globals['_MYSQLCONFIG8_0_LOGSLOWFILTERTYPE']._serialized_end=7986
  _globals['_MYSQLCONFIG8_0_BINLOGTRANSACTIONDEPENDENCYTRACKING']._serialized_start=7989
  _globals['_MYSQLCONFIG8_0_BINLOGTRANSACTIONDEPENDENCYTRACKING']._serialized_end=8136
  _globals['_MYSQLCONFIG8_0_AUDITLOGPOLICY']._serialized_start=8138
  _globals['_MYSQLCONFIG8_0_AUDITLOGPOLICY']._serialized_end=8232
  _globals['_MYSQLCONFIG8_0_INNODBCHANGEBUFFERING']._serialized_start=8235
  _globals['_MYSQLCONFIG8_0_INNODBCHANGEBUFFERING']._serialized_end=8513
  _globals['_MYSQLCONFIGSET8_0']._serialized_start=8516
  _globals['_MYSQLCONFIGSET8_0']._serialized_end=8756
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.workflows.v1.workflow_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class WorkflowServiceStub:
    """Set of methods for managing Workflows."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.CreateWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates Workflow in specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.UpdateWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified Workflow."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowResponse,
    ]
    """Retrieves specified Workflow."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.DeleteWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified Workflow."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsResponse,
    ]
    """Retrieves list of Workflows in specified folder."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsResponse,
    ]
    """Lists operations for specified Workflow."""

class WorkflowServiceAsyncStub:
    """Set of methods for managing Workflows."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.CreateWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates Workflow in specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.UpdateWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates specified Workflow."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowResponse,
    ]
    """Retrieves specified Workflow."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.DeleteWorkflowRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes specified Workflow."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsResponse,
    ]
    """Retrieves list of Workflows in specified folder."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsRequest,
        yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsResponse,
    ]
    """Lists operations for specified Workflow."""

class WorkflowServiceServicer(metaclass=abc.ABCMeta):
    """Set of methods for managing Workflows."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.CreateWorkflowRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates Workflow in specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.UpdateWorkflowRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates specified Workflow."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.GetWorkflowResponse]]:
        """Retrieves specified Workflow."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.DeleteWorkflowRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes specified Workflow."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListWorkflowsResponse]]:
        """Retrieves list of Workflows in specified folder."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsResponse, collections.abc.Awaitable[yandex.cloud.serverless.workflows.v1.workflow_service_pb2.ListOperationsResponse]]:
        """Lists operations for specified Workflow."""

def add_WorkflowServiceServicer_to_server(servicer: WorkflowServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/v1/lock_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/v1/lock_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/marketplace/licensemanager/v1/lock_service.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\'\n\x0eGetLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x43reateLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x45nsureLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x43reateLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"%\n\x12\x45nsureLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"*\n\x11\x44\x65leteLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x44\x65leteLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"[\n#GetLockByInstanceAndResourceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xbd\x01\n\x10ListLocksRequest\x12\x19\n\x0bresource_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x11ListLocksResponse\x12?\n\x05locks\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbd\t\n\x0bLockService\x12\xac\x01\n\x03Get\x12:.yandex.cloud.marketplace.licensemanager.v1.GetLockRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"7\x82\xd3\xe4\x93\x02\x31\x12//marketplace/license-manager/v1/locks/{lock_id}\x12\xe5\x01\n\x18GetByInstanceAndResource\x12O.yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"F\x82\xd3\xe4\x93\x02@\x12>/marketplace/license-manager/v1/locks:getByInstanceAndResource\x12\xb2\x01\n\x04List\x12<.yandex.cloud.marketplace.licensemanager.v1.ListLocksRequest\x1a=.yandex.cloud.marketplace.licensemanager.v1.ListLocksResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/marketplace/license-manager/v1/locks\x12\xba\x01\n\x06\x43reate\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x82\xd3\xe4\x93\x02*\"%/marketplace/license-manager/v1/locks:\x01*\x12\xcf\x01\n\x06\x45nsure\x12=.yandex.cloud.marketplace.licensemanager.v1.EnsureLockRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*\x1a\n\x12\x45nsureLockMetadata\x12\x04Lock\x82\xd3\xe4\x93\x02?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\x01*\x12\xd2\x01\n\x06\x44\x65lete\x12=.yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*+\n\x12\x44\x65leteLockMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31*//marketplace/license-manager/v1/locks/{lock_id}B\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._loaded_options = None
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOCKREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_CREATELOCKREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOCKREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATELOCKREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETELOCKREQUEST'].fields_by_name['lock_id']._loaded_options = None
  _globals['_DELETELOCKREQUEST'].fields_by_name['lock_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LOCKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//marketplace/license-manager/v1/locks/{lock_id}'
  _globals['_LOCKSERVICE'].methods_by_name['GetByInstanceAndResource']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['GetByInstanceAndResource']._serialized_options = b'\202\323\344\223\002@\022>/marketplace/license-manager/v1/locks:getByInstanceAndResource'
  _globals['_LOCKSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\'\022%/marketplace/license-manager/v1/locks'
  _globals['_LOCKSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateLockMetadata\022\004Lock\202\323\344\223\002*\"%/marketplace/license-manager/v1/locks:\001*'
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._serialized_options = b'\262\322*\032\n\022EnsureLockMetadata\022\004Lock\202\323\344\223\002?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\001*'
  _globals['_LOCKSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteLockMetadata\022\025google.protobuf.Empty\202\323\344\223\0021*//marketplace/license-manager/v1/locks/{lock_id}'
  _globals['_GETLOCKREQUEST']._serialized_start=299
  _globals['_GETLOCKREQUEST']._serialized_end=338
  _globals['_CREATELOCKREQUEST']._serialized_start=340
  _globals['_CREATELOCKREQUEST']._serialized_end=413
  _globals['_ENSURELOCKREQUEST']._serialized_start=415
  _globals['_ENSURELOCKREQUEST']._serialized_end=488
  _globals['_CREATELOCKMETADATA']._serialized_start=490
  _globals['_CREATELOCKMETADATA']._serialized_end=527
  _globals['_ENSURELOCKMETADATA']._serialized_start=529
  _globals['_ENSURELOCKMETADATA']._serialized_end=566
  _globals['_DELETELOCKREQUEST']._serialized_start=568
  _globals['_DELETELOCKREQUEST']._serialized_end=610
  _globals['_DELETELOCKMETADATA']._serialized_start=612
  _globals['_DELETELOCKMETADATA']._serialized_end=649
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST']._serialized_start=651
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST']._serialized_end=742
  _globals['_LISTLOCKSREQUEST']._serialized_start=745
  _globals['_LISTLOCKSREQUEST']._serialized_end=934
  _globals['_LISTLOCKSRESPONSE']._serialized_start=936
  _globals['_LISTLOCKSRESPONSE']._serialized_end=1045
  _globals['_LOCKSERVICE']._serialized_start=1048
  _globals['_LOCKSERVICE']._serialized_end=2261
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/stt/v2/stt_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/stt/v2/stt_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/stt/v2/stt_service.proto\x12\x16yandex.cloud.ai.stt.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\"\x93\x01\n\x1dLongRunningRecognitionRequest\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.stt.v2.RecognitionConfig\x12\x37\n\x05\x61udio\x18\x02 \x01(\x0b\x32(.yandex.cloud.ai.stt.v2.RecognitionAudio\"a\n\x1eLongRunningRecognitionResponse\x12?\n\x06\x63hunks\x18\x01 \x03(\x0b\x32/.yandex.cloud.ai.stt.v2.SpeechRecognitionResult\"\x88\x01\n\x1bStreamingRecognitionRequest\x12;\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).yandex.cloud.ai.stt.v2.RecognitionConfigH\x00\x12\x17\n\raudio_content\x18\x02 \x01(\x0cH\x00\x42\x13\n\x11streaming_request\"}\n\x1cStreamingRecognitionResponse\x12>\n\x06\x63hunks\x18\x01 \x03(\x0b\x32..yandex.cloud.ai.stt.v2.SpeechRecognitionChunkJ\x04\x08\x02\x10\x03R\x17\x65nd_of_single_utterance\"D\n\x10RecognitionAudio\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\x0e\n\x0c\x61udio_source\"f\n\x11RecognitionConfig\x12>\n\rspecification\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.stt.v2.RecognitionSpec\x12\x11\n\tfolder_id\x18\x02 \x01(\t\"\x99\x03\n\x0fRecognitionSpec\x12M\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.ai.stt.v2.RecognitionSpec.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\x03\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x18\n\x10profanity_filter\x18\x04 \x01(\x08\x12\r\n\x05model\x18\x05 \x01(\t\x12\x17\n\x0fpartial_results\x18\x07 \x01(\x08\x12\x18\n\x10single_utterance\x18\x08 \x01(\x08\x12\x1b\n\x13\x61udio_channel_count\x18\t \x01(\x03\x12\x13\n\x0braw_results\x18\n \x01(\x08\x12\x17\n\x0fliterature_text\x18\x0b \x01(\x08\"X\n\rAudioEncoding\x12\x1e\n\x1a\x41UDIO_ENCODING_UNSPECIFIED\x10\x00\x12\x10\n\x0cLINEAR16_PCM\x10\x01\x12\x0c\n\x08OGG_OPUS\x10\x02\x12\x07\n\x03MP3\x10\x03J\x04\x08\x06\x10\x07\"\x8d\x01\n\x16SpeechRecognitionChunk\x12J\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative\x12\r\n\x05\x66inal\x18\x02 \x01(\x08\x12\x18\n\x10\x65nd_of_utterance\x18\x03 \x01(\x08\"z\n\x17SpeechRecognitionResult\x12J\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.ai.stt.v2.SpeechRecognitionAlternative\x12\x13\n\x0b\x63hannel_tag\x18\x02 \x01(\x03\"q\n\x1cSpeechRecognitionAlternative\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12/\n\x05words\x18\x03 \x03(\x0b\x32 .yandex.cloud.ai.stt.v2.WordInfo\"\x88\x01\n\x08WordInfo\x12-\n\nstart_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04word\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x02\x32\xdb\x02\n\nSttService\x12\xc4\x01\n\x14LongRunningRecognize\x12\x35.yandex.cloud.ai.stt.v2.LongRunningRecognitionRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2* \x12\x1eLongRunningRecognitionResponse\x82\xd3\xe4\x93\x02(\"#/speech/stt/v2/longRunningRecognize:\x01*\x12\x85\x01\n\x12StreamingRecognize\x12\x33.yandex.cloud.ai.stt.v2.StreamingRecognitionRequest\x1a\x34.yandex.cloud.ai.stt.v2.StreamingRecognitionResponse\"\x00(\x01\x30\x01\x42\\\n\x1ayandex.cloud.api.ai.stt.v2Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v2;sttb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.stt.v2.stt_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.ai.stt.v2Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/stt/v2;stt'
  _globals['_STTSERVICE'].methods_by_name['LongRunningRecognize']._loaded_options = None
  _globals['_STTSERVICE'].methods_by_name['LongRunningRecognize']._serialized_options = b'\262\322* \022\036LongRunningRecognitionResponse\202\323\344\223\002(\"#/speech/stt/v2/longRunningRecognize:\001*'
  _globals['_LONGRUNNINGRECOGNITIONREQUEST']._serialized_start=205
  _globals['_LONGRUNNINGRECOGNITIONREQUEST']._serialized_end=352
  _globals['_LONGRUNNINGRECOGNITIONRESPONSE']._serialized_start=354
  _globals['_LONGRUNNINGRECOGNITIONRESPONSE']._serialized_end=451
  _globals['_STREAMINGRECOGNITIONREQUEST']._serialized_start=454
  _globals['_STREAMINGRECOGNITIONREQUEST']._serialized_end=590
  _globals['_STREAMINGRECOGNITIONRESPONSE']._serialized_start=592
  _globals['_STREAMINGRECOGNITIONRESPONSE']._serialized_end=717
  _globals['_RECOGNITIONAUDIO']._serialized_start=719
  _globals['_RECOGNITIONAUDIO']._serialized_end=787
  _globals['_RECOGNITIONCONFIG']._serialized_start=789
  _globals['_RECOGNITIONCONFIG']._serialized_end=891
  _globals['_RECOGNITIONSPEC']._serialized_start=894
  _globals['_RECOGNITIONSPEC']._serialized_end=1303
  _globals['_RECOGNITIONSPEC_AUDIOENCODING']._serialized_start=1209
  _globals['_RECOGNITIONSPEC_AUDIOENCODING']._serialized_end=1297
  _globals['_SPEECHRECOGNITIONCHUNK']._serialized_start=1306
  _globals['_SPEECHRECOGNITIONCHUNK']._serialized_end=1447
  _globals['_SPEECHRECOGNITIONRESULT']._serialized_start=1449
  _globals['_SPEECHRECOGNITIONRESULT']._serialized_end=1571
  _globals['_SPEECHRECOGNITIONALTERNATIVE']._serialized_start=1573
  _globals['_SPEECHRECOGNITIONALTERNATIVE']._serialized_end=1686
  _globals['_WORDINFO']._serialized_start=1689
  _globals['_WORDINFO']._serialized_end=1825
  _globals['_STTSERVICE']._serialized_start=1828
  _globals['_STTSERVICE']._serialized_end=2175
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PresignObjectRequest(google.protobuf.message.Message):
    """PresignObjectRequest represents a single object presign request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXPIRES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    AS_ATTACHMENT_FIELD_NUMBER: builtins.int
    expires: builtins.int
    """Expiration time in seconds"""
    name: builtins.str
    """Object name/key"""
    method: builtins.str
    """HTTP method (GET, PUT, HEAD)"""
    version_id: builtins.str
    """Object version ID (optional)"""
    as_attachment: builtins.bool
    """Whether to force download as attachment"""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Additional HTTP headers"""

    def __init__(
        self,
        *,
        expires: builtins.int = ...,
        name: builtins.str = ...,
        method: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version_id: builtins.str = ...,
        as_attachment: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["as_attachment", b"as_attachment", "expires", b"expires", "headers", b"headers", "method", b"method", "name", b"name", "version_id", b"version_id"]) -> None: ...

global___PresignObjectRequest = PresignObjectRequest

@typing.final
class PresignURLsRequest(google.protobuf.message.Message):
    """PresignURLsRequest represents the request for presigning URLs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    PRESIGN_HOST_FIELD_NUMBER: builtins.int
    OBJECTS_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    """Bucket name"""
    presign_host: builtins.str
    """Custom presign host (optional)"""
    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PresignObjectRequest]:
        """List of objects to presign"""

    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        presign_host: builtins.str = ...,
        objects: collections.abc.Iterable[global___PresignObjectRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_name", b"bucket_name", "objects", b"objects", "presign_host", b"presign_host"]) -> None: ...

global___PresignURLsRequest = PresignURLsRequest

@typing.final
class PresignURLsResponse(google.protobuf.message.Message):
    """PresignURLsResponse represents the response with presigned URLs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URLS_FIELD_NUMBER: builtins.int
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of presigned URLs corresponding to the requested objects"""

    def __init__(
        self,
        *,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["urls", b"urls"]) -> None: ...

global___PresignURLsResponse = PresignURLsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.hardware_pool_pb2
import yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HardwarePoolServiceStub:
    """A set of methods to retrieve information about HardwarePool resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool,
    ]
    """Returns the specific HardwarePool resource.

    To get the list of available HardwarePool resource, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse,
    ]
    """Retrieves the list of HardwarePool resources."""

class HardwarePoolServiceAsyncStub:
    """A set of methods to retrieve information about HardwarePool resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool,
    ]
    """Returns the specific HardwarePool resource.

    To get the list of available HardwarePool resource, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse,
    ]
    """Retrieves the list of HardwarePool resources."""

class HardwarePoolServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods to retrieve information about HardwarePool resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool]]:
        """Returns the specific HardwarePool resource.

        To get the list of available HardwarePool resource, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse]]:
        """Retrieves the list of HardwarePool resources."""

def add_HardwarePoolServiceServicer_to_server(servicer: HardwarePoolServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.instance_service_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ProductIDs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.
        """

    def __init__(
        self,
        *,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["product_ids", b"product_ids"]) -> None: ...

global___ProductIDs = ProductIDs

@typing.final
class BootDiskSpec(google.protobuf.message.Message):
    """Specification used to determine required product_ids
    You can specify product ids explicitly or use disk_id|image_id|snapshot_id to infer products ids from them.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_ID_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    disk_id: builtins.str
    """Disk ID."""
    image_id: builtins.str
    """Image ID."""
    snapshot_id: builtins.str
    """Snapshot ID."""
    @property
    def product_ids(self) -> global___ProductIDs:
        """Product IDs."""

    def __init__(
        self,
        *,
        disk_id: builtins.str = ...,
        image_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        product_ids: global___ProductIDs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_source", b"boot_source", "disk_id", b"disk_id", "image_id", b"image_id", "product_ids", b"product_ids", "snapshot_id", b"snapshot_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_source", b"boot_source", "disk_id", b"disk_id", "image_id", b"image_id", "product_ids", b"product_ids", "snapshot_id", b"snapshot_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["boot_source", b"boot_source"]) -> typing.Literal["disk_id", "image_id", "snapshot_id", "product_ids"] | None: ...

global___BootDiskSpec = BootDiskSpec

@typing.final
class ReservedInstancePool(google.protobuf.message.Message):
    """A Reserved Instance Pool resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class SlotStats(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_FIELD_NUMBER: builtins.int
        USED_FIELD_NUMBER: builtins.int
        AVAILABLE_FIELD_NUMBER: builtins.int
        UNAVAILABLE_FIELD_NUMBER: builtins.int
        PENDING_FIELD_NUMBER: builtins.int
        total: builtins.int
        """Equals to pool size (and equals to the sum of the following fields)"""
        used: builtins.int
        """Number of slots used by running instances"""
        available: builtins.int
        """Number of slots available for instances (but not currently used)"""
        unavailable: builtins.int
        """Number of slots unavailable for some reason (for example because of underlying host failure)"""
        pending: builtins.int
        """Number of slots requested for async update, but still waiting for resources and not yet available for usage"""
        def __init__(
            self,
            *,
            total: builtins.int = ...,
            used: builtins.int = ...,
            available: builtins.int = ...,
            unavailable: builtins.int = ...,
            pending: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["available", b"available", "pending", b"pending", "total", b"total", "unavailable", b"unavailable", "used", b"used"]) -> None: ...

    @typing.final
    class InstanceStats(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_FIELD_NUMBER: builtins.int
        total: builtins.int
        """Total number of instances linked to the pool"""
        def __init__(
            self,
            *,
            total: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["total", b"total"]) -> None: ...

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    PRODUCT_IDS_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    COMMITTED_SIZE_FIELD_NUMBER: builtins.int
    ALLOW_OVERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    SLOT_STATS_FIELD_NUMBER: builtins.int
    INSTANCE_STATS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the pool."""
    zone_id: builtins.str
    """ID of the availability zone where the pool resides."""
    cloud_id: builtins.str
    """ID of the cloud that the pool belongs to."""
    folder_id: builtins.str
    """ID of the folder that the pool belongs to."""
    name: builtins.str
    """Name of the pool. 1-63 characters long."""
    description: builtins.str
    """Description of the pool. 0-256 characters long."""
    platform_id: builtins.str
    """ID of the hardware platform configuration for pool instances."""
    size: builtins.int
    """Desired size of the pool (number of slots for instances in this pool)."""
    committed_size: builtins.int
    """Equals to the size field except when updates occur with allow_pending=true. In those cases, committed_size equals only the number of non-pending slots."""
    allow_oversubscription: builtins.bool
    """Allows the pool to contain more linked instances than the number of available slots (size without pending or unavailable slots).
    While running instances are still limited by available slots, stopped instances can exceed this limit.
    Warning: When this option is enabled, attempting to start more instances than the number of available slots will result in a "Not Enough Resources" error.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. Maximum of 64 per resource."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def resources_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec:
        """Computing resources of pool instances, such as the amount of memory and number of cores."""

    @property
    def gpu_settings(self) -> yandex.cloud.compute.v1.instance_pb2.GpuSettings:
        """GPU settings."""

    @property
    def product_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """License IDs that indicate which licenses are attached to resource.
        License IDs are used to calculate additional charges for the use of the virtual machine.
        """

    @property
    def network_settings(self) -> yandex.cloud.compute.v1.instance_pb2.NetworkSettings:
        """Network Settings."""

    @property
    def slot_stats(self) -> global___ReservedInstancePool.SlotStats:
        """Statuses of the pool slots"""

    @property
    def instance_stats(self) -> global___ReservedInstancePool.InstanceStats:
        """Stats for instances of the pool"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        platform_id: builtins.str = ...,
        resources_spec: yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec | None = ...,
        gpu_settings: yandex.cloud.compute.v1.instance_pb2.GpuSettings | None = ...,
        product_ids: collections.abc.Iterable[builtins.str] | None = ...,
        network_settings: yandex.cloud.compute.v1.instance_pb2.NetworkSettings | None = ...,
        size: builtins.int = ...,
        committed_size: builtins.int = ...,
        allow_oversubscription: builtins.bool = ...,
        slot_stats: global___ReservedInstancePool.SlotStats | None = ...,
        instance_stats: global___ReservedInstancePool.InstanceStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "gpu_settings", b"gpu_settings", "instance_stats", b"instance_stats", "network_settings", b"network_settings", "resources_spec", b"resources_spec", "slot_stats", b"slot_stats"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_oversubscription", b"allow_oversubscription", "cloud_id", b"cloud_id", "committed_size", b"committed_size", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "gpu_settings", b"gpu_settings", "id", b"id", "instance_stats", b"instance_stats", "labels", b"labels", "name", b"name", "network_settings", b"network_settings", "platform_id", b"platform_id", "product_ids", b"product_ids", "resources_spec", b"resources_spec", "size", b"size", "slot_stats", b"slot_stats", "zone_id", b"zone_id"]) -> None: ...

global___ReservedInstancePool = ReservedInstancePool
